import { TravisClient } from '@imqueue/travis';
/**
 * Returns encrypted secure key for travis sensitive data.
 *
 * @see https://docs.travis-ci.com/user/encryption-keys/
 * @param {string} repository - git repository owner/name
 * @param {string} data - sensitive data to encrypt
 * @param {string} github_token - token if auth required (pro mode)
 * @return {Promise<string>}
 */
export declare function travisEncrypt(repository: string, data: string, github_token?: string): Promise<string>;
/**
 * Tries perform travis sync
 *
 * @param {TravisClient} travis - authenticated client
 * @param {number} [retry] - current retry
 * @param {number} maxRetries - max number of retries
 * @param {number} delay - delay in milliseconds before result return
 */
export declare function trySyncBuilds(travis: TravisClient, retry?: number, maxRetries?: number, delay?: number): Promise<boolean>;
/**
 * Enables builds for a given repository
 *
 * @param {string} owner
 * @param {string} repo
 * @param {string} github_token
 * @return {Promise<void>}
 */
export declare function enableBuilds(owner: string, repo: string, github_token: string, isPrivate: boolean): Promise<boolean>;
