"use strict";
var _a;
Object.defineProperty(exports, "__esModule", { value: true });
exports.handler = exports.builder = exports.describe = exports.command = void 0;
const chalk = require("chalk");
const lib_1 = require("../../lib");
let PROGRAM = '';
// noinspection JSUnusedGlobalSymbols
_a = {
    command: 'get [option]',
    describe: 'Prints value for given option from config. If option is ' +
        'not provided, will list all config options',
    async builder(yargs) {
        PROGRAM = (await yargs.argv).$0;
        return yargs
            .option('j', {
            alias: 'json',
            boolean: true,
            default: false,
            describe: 'Prints config in JSON format (only if ' +
                'option is not passed)'
        })
            .default('option', '')
            .describe('option', 'Config option to display value [optional]');
    },
    handler(argv) {
        try {
            const config = (0, lib_1.loadConfig)();
            const options = config && Object.keys(config) || [];
            if (!options.length) {
                return process.stdout.write(chalk.bold.yellow('Config is empty. Try to init if first by running:') +
                    '\n\n  $ ' +
                    chalk.cyan(`${PROGRAM} config init`) + '\n\n');
            }
            if (argv.option) {
                return process.stdout.write(JSON.stringify(config[argv.option]) + '\n');
            }
            process.stdout.write(chalk.bold.green('IMQ CLI Config:') + '\n');
            if (argv.json) {
                return process.stdout.write(chalk.cyan(JSON.stringify(config, null, 2)) + '\n');
            }
            for (let option of options) {
                process.stdout.write(chalk.yellow(`${option}`) + ' = ' +
                    chalk.cyan(JSON.stringify(config[option])) + '\n');
            }
        }
        catch (err) {
            (0, lib_1.printError)(err);
        }
    }
}, exports.command = _a.command, exports.describe = _a.describe, exports.builder = _a.builder, exports.handler = _a.handler;
//# sourceMappingURL=get.js.map